
LINE = '-'
DOTTED = 'o'
LINE_DOTTED = '-o'

YUPI_COLORS = [
    '#3489b1',
    '#a14383',
    '#e5d935',
    '#af3c3c',
    '#54ac43',
    '#e88d26',
    '#3c4baf'
]

YUPI_LIGHT_COLORS = [
    '#99d2ec',
    '#eaa0d2',
    '#fdf584',
    '#ea8080',
    '#a6ec98',
    '#f7c790'
]

BLUE = YUPI_COLORS[0]
MAGENTA = YUPI_COLORS[1]
YELLOW = YUPI_COLORS[2]
RED = YUPI_COLORS[3]
GREEN = YUPI_COLORS[4]
ORANGE = YUPI_COLORS[5]
MID_BLUE = YUPI_COLORS[6]

LIGHT_BLUE = YUPI_LIGHT_COLORS[0]
LIGHT_MAGENTA = YUPI_LIGHT_COLORS[1]
LIGHT_YELLOW = YUPI_LIGHT_COLORS[2]
LIGHT_RED = YUPI_LIGHT_COLORS[3]
LIGHT_GREEN = YUPI_LIGHT_COLORS[4]
LIGHT_ORANGE = YUPI_LIGHT_COLORS[5]
